/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */
import React, { Component } from "react";
import { AWSAuthenticationProviderType, AWSUserData, Credentials } from "../../../contexts/auth";
import { ValidUserInformation } from "../../../utils/cognitoService";
import { JWT } from "aws-amplify/auth";
export interface Props {
    configureAmplify: () => void;
    failOnNoLegalGroup?: boolean;
    legalGroups?: string[];
}
export interface State {
    hasAuthenticated: boolean;
    isNewPasswordRequired: boolean;
    isLoading: boolean;
    userData: AWSUserData | undefined;
    loginError: undefined | {
        [key: string]: any;
    } | string;
}
interface FetchSettings {
    headers?: Headers;
    [key: string]: any;
}
export declare class AWSAuthenticationProvider extends Component<React.PropsWithChildren<Props>, State> implements AWSAuthenticationProviderType {
    static defaultProps: {
        failOnNoLegalGroup: boolean;
        legalGroups: never[];
    };
    constructor(props: Props);
    componentDidMount(): void;
    componentDidUpdate(): void;
    checkIsAuthenticated: () => Promise<void>;
    generateSettingsWithAuthFrom: (token?: JWT, settings?: FetchSettings) => FetchSettings | undefined;
    fetchAuthed: (url: string, token?: JWT, settings?: FetchSettings) => Promise<Response>;
    hasAuthenticated: () => boolean;
    getUserData: () => AWSUserData | undefined;
    getUserGroups: () => string[];
    login: (credentials: Credentials) => Promise<void>;
    processSuccessfulAuth: (userData: ValidUserInformation) => void;
    logout: (error?: any) => Promise<void>;
    completePassword: (newPassword: string) => void;
    refreshSession: () => Promise<void>;
    render(): import("react/jsx-runtime").JSX.Element;
}
export {};
