function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { Component } from "react";
import { AuthContext } from "../../../contexts/auth";
import { cognitoCheckIsAuthenticated, cognitoCompletePassword, cognitoLogin, cognitoLogout, cognitoRefreshToken, ValidUserInformation } from "../../../utils/cognitoService";
export class AWSAuthenticationProvider extends Component {
  constructor(props) {
    super(props);
    _defineProperty(this, "checkIsAuthenticated", async () => {
      try {
        const result = await cognitoCheckIsAuthenticated(this.props.failOnNoLegalGroup, this.props.legalGroups);
        this.processSuccessfulAuth(result);
        //eslint-disable-next-line
      } catch (error) {
        this.logout();
      }
    });
    _defineProperty(this, "generateSettingsWithAuthFrom", (token, settings) => {
      if (settings !== undefined) {
        if ("headers" in settings) {
          if (!settings.headers?.has("Authorization")) {
            const settingsWithAuth = Object.assign({}, settings);
            settingsWithAuth.headers?.set("Authorization", "Bearer " + (token ? token : this.state.userData?.idToken.toString()));
            return settingsWithAuth;
          }
        } else {
          return Object.assign(settings, {
            headers: new Headers({
              Authorization: "Bearer " + (token ? token : this.state.userData?.idToken)
            })
          });
        }
      } else {
        return {
          headers: new Headers({
            Authorization: "Bearer " + (token ? token : this.state.userData?.idToken)
          })
        };
      }
    });
    //In Amplify 6 the fetchAuthedSession Function handles the renewing of sessions
    _defineProperty(this, "fetchAuthed", (url, token, settings) => {
      try {
        this.checkIsAuthenticated();
        return fetch(url, this.generateSettingsWithAuthFrom(token, settings)).then(response => {
          return response;
        });
        //eslint-disable-next-line
      } catch (error) {
        this.logout();
        return new Promise(resolve => {
          resolve(new Response(null, {
            status: 401,
            statusText: "Unauthorized"
          }));
        });
      }
    });
    _defineProperty(this, "hasAuthenticated", () => {
      return this.state.hasAuthenticated;
    });
    _defineProperty(this, "getUserData", () => {
      return this.state.userData;
    });
    _defineProperty(this, "getUserGroups", () => {
      return this.state.userData ? this.state.userData.groups : [];
    });
    _defineProperty(this, "login", async credentials => {
      this.setState({
        isLoading: true,
        loginError: undefined
      });
      try {
        const result = await cognitoLogin(credentials, this.props.failOnNoLegalGroup, this.props.legalGroups);
        if (result instanceof ValidUserInformation) {
          this.processSuccessfulAuth(result);
        } else {
          this.setState({
            hasAuthenticated: false,
            isNewPasswordRequired: true
          });
        }
      } catch (error) {
        await this.logout(error);
      } finally {
        this.setState({
          isLoading: false
        });
      }
    });
    _defineProperty(this, "processSuccessfulAuth", userData => {
      if (!this.state.hasAuthenticated || this.state.isNewPasswordRequired) {
        this.setState({
          hasAuthenticated: true,
          isNewPasswordRequired: false,
          userData: userData,
          loginError: undefined
        });
      }
    });
    _defineProperty(this, "logout", async error => {
      this.setState({
        isLoading: true
      });
      cognitoLogout().catch(err => {
        console.log("error signing out: ", err);
      }).finally(() => {
        this.setState({
          isLoading: false,
          hasAuthenticated: false,
          userData: undefined,
          loginError: error ? error : undefined
        });
      });
    });
    _defineProperty(this, "completePassword", newPassword => {
      this.setState({
        isLoading: true
      });
      cognitoCompletePassword(newPassword, this.props.failOnNoLegalGroup, this.props.legalGroups).then(result => this.processSuccessfulAuth(result)).catch(error => this.logout(error)).then(() => {
        this.setState({
          isLoading: false
        });
      });
    });
    _defineProperty(this, "refreshSession", async () => {
      try {
        const response = await cognitoRefreshToken(this.props.failOnNoLegalGroup, this.props.legalGroups);
        if (response instanceof ValidUserInformation) {
          this.processSuccessfulAuth(response);
        }
      } catch (error) {
        this.logout(error);
      }
    });
    this.state = {
      hasAuthenticated: false,
      // true if user is authenticated
      isNewPasswordRequired: false,
      // true if user logs in for the first time with his temp password and has to set a new one
      isLoading: false,
      // true if user is in process of logging in
      userData: undefined,
      // contains user information; undefined if no user is logged in
      loginError: undefined
    };
  }
  componentDidMount() {
    this.props.configureAmplify();
    this.checkIsAuthenticated();
  }
  componentDidUpdate() {
    if (this.state.hasAuthenticated) {
      this.checkIsAuthenticated();
    }
  }
  render() {
    return /*#__PURE__*/React.createElement(AuthContext.Provider, {
      value: {
        ...this.state,
        login: this.login,
        completePassword: this.completePassword,
        logout: this.logout,
        getUserData: this.getUserData,
        getUserGroups: this.getUserGroups,
        refreshSession: this.refreshSession,
        hasAuthenticated: this.hasAuthenticated,
        fetchAuthed: this.fetchAuthed
      }
    }, this.props.children);
  }
}
_defineProperty(AWSAuthenticationProvider, "defaultProps", {
  failOnNoLegalGroup: false,
  legalGroups: []
});