/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext, useState } from "react";
import { DEFAULT_ELEMENTSIZE, GREY5, WHITE } from "../../constants";
import { generateHashOfLength } from "../../utils/hash";
import { Tooltip } from "primereact/tooltip";
import "./contentbar.css";
import { ColorSettingsContext } from "../../contexts/colorsettings";
import { useTranslator } from "../internationalization/translators";
import { determineCurrentColor } from "../../utils/determineCurrentColor";
export const DefaultContentSelectionElement = props => {
  const [hovering, setHovering] = useState(false);
  const translationFunction = useTranslator();
  const colorSettingsContext = useContext(ColorSettingsContext);
  const tabBackgroundDefaultColor = colorSettingsContext.currentColors.contentbar.tabs.backgroundDefaultColor;
  const tabBackgroundHoverColor = colorSettingsContext.currentColors.contentbar.tabs.backgroundHoverColor;
  const tabBackgroundActiveColor = colorSettingsContext.currentColors.contentbar.tabs.backgroundActiveColor;
  const textDefaultColor = colorSettingsContext.currentColors.contentbar.tabs.textDefaultColor;
  const textHoverColor = colorSettingsContext.currentColors.contentbar.tabs.textHoverColor;
  const textActiveColor = colorSettingsContext.currentColors.contentbar.tabs.textActiveColor;
  const iconDefaultColor = colorSettingsContext.currentColors.contentbar.tabs.iconDefaultColor;
  const iconHoverColor = colorSettingsContext.currentColors.contentbar.tabs.iconHoverColor;
  const iconActiveColor = colorSettingsContext.currentColors.contentbar.tabs.iconActiveColor;
  const tabState = {
    isActive: !!props.selected,
    isHovering: hovering,
    isDisabled: false
  };
  const name = typeof props.displayName === "string" ? props.displayName : props.displayName(translationFunction);
  const tabStyle = {
    cursor: props.selected ? "default" : "pointer",
    backgroundColor: determineCurrentColor(tabState, {
      defaultColor: tabBackgroundDefaultColor,
      hoverColor: tabBackgroundHoverColor,
      activeColor: tabBackgroundActiveColor
    }),
    color: determineCurrentColor(tabState, {
      defaultColor: textDefaultColor,
      hoverColor: textHoverColor,
      activeColor: textActiveColor
    }),
    height: `${DEFAULT_ELEMENTSIZE}px`,
    width: `${props.width}px`,
    alignItems: "center",
    borderRight: "1px solid " + (colorSettingsContext?.darkmode ? GREY5 : WHITE)
  };
  const closingIconStyle = {
    color: determineCurrentColor(tabState, {
      defaultColor: iconDefaultColor,
      hoverColor: iconHoverColor,
      activeColor: iconActiveColor
    }),
    marginRight: "8px"
  };
  const handleOnCloseEvent = e => {
    e.stopPropagation();
    if (props.onClose) {
      props.onClose(props.id, props.idOfFirstElement);
    }
  };
  const handleOnClickEvent = () => {
    if (props.onClick) {
      props.onClick(props.id);
    }
  };
  const identifier = generateHashOfLength(4);
  const identifierLegal = "a" + identifier;
  const identifierWithDot = "." + identifierLegal;
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "flex align-items-center element-hover",
    style: tabStyle,
    onMouseEnter: () => setHovering(true),
    onMouseLeave: () => setHovering(false),
    onClick: handleOnClickEvent
  }, props.displayName.length >= 20 ? /*#__PURE__*/React.createElement("div", {
    style: {
      width: "100%",
      display: "flex",
      justifyContent: "center",
      alignItems: "center"
    },
    className: identifierLegal
  }, /*#__PURE__*/React.createElement("span", {
    className: "m-auto font-semibold "
  }, name.slice(0, 20) + "..."), /*#__PURE__*/React.createElement(Tooltip, {
    id: "change-color",
    content: name,
    target: identifierWithDot
  })) : /*#__PURE__*/React.createElement("div", {
    className: "m-auto font-semibold "
  }, name), props.closable === true ? /*#__PURE__*/React.createElement("div", {
    style: {
      position: "absolute",
      right: "5px"
    }
  }, /*#__PURE__*/React.createElement("i", {
    onClick: event => handleOnCloseEvent(event),
    style: closingIconStyle,
    className: "pi pi-times tabelements-only"
  })) : /*#__PURE__*/React.createElement(React.Fragment, null)));
};