/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext } from "react";
import { CookiesProvider } from "react-cookie";
import { AuthContext } from "../contexts/auth";
import { DefaultLanguageProvider } from "./internationalization/defaultLanguageProvider";
import { DummyAuthenticationProvider } from "./authentication/default/dummyAuthenticationProvider";
import { ColorProvider } from "../coloring/colorProvider";
import { DEFAULT_FALLBACK_LANGUAGE } from "../constants";
import { BrowserRouter } from "react-router-dom";

// Create this type to make fallbackLang optional for the user.

export const GlobalDataLayer = props => {
  const authContext = useContext(AuthContext);
  const AuthenticationProvider = authContext ? React.Fragment : DummyAuthenticationProvider;
  const fallbackLang = props.languageOptions?.fallbackLang ?? DEFAULT_FALLBACK_LANGUAGE;
  const initialLang = props.languageOptions?.initialLang ?? DEFAULT_FALLBACK_LANGUAGE;
  const languageOptions = {
    fallbackLang: fallbackLang,
    initialLang: initialLang
  };
  return /*#__PURE__*/React.createElement(CookiesProvider, null, /*#__PURE__*/React.createElement(AuthenticationProvider, null, /*#__PURE__*/React.createElement(DefaultLanguageProvider, {
    languageOptions: languageOptions,
    translations: props.translations,
    initI18Next: props.initI18Next
  }, /*#__PURE__*/React.createElement(ColorProvider, props.colorSettings, /*#__PURE__*/React.createElement(BrowserRouter, null, props.children)))));
};