/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */
import React from "react";
import { ContextMenu } from "primereact/contextmenu";
interface MenuItemCommandParams {
    originalEvent: React.SyntheticEvent;
    item: MenuItem;
}
interface MenuItemOptions {
    className: string;
    labelClassName: string;
    iconClassName: string;
    element: React.ReactNode;
    props: any;
    onClick(event: React.SyntheticEvent): void;
    [key: string]: any;
}
type MenuItemTemplateType = React.ReactNode | ((item: MenuItem, options: MenuItemOptions) => React.ReactNode);
export interface MenuItem {
    label?: string;
    icon?: any;
    url?: string;
    items?: MenuItem[] | MenuItem[][];
    expanded?: boolean;
    disabled?: boolean;
    target?: string;
    separator?: boolean;
    style?: object;
    className?: string;
    template?: MenuItemTemplateType;
    command?(e: MenuItemCommandParams): void;
    [key: string]: any;
}
export interface SettingsMenuOptions {
    additionalItems?: MenuItem[];
    hideLanguageSelection?: boolean;
    hideColorThemeToggler?: boolean;
}
interface Props {
    hideMenu: (e: React.KeyboardEvent) => void;
    menuOptions?: SettingsMenuOptions;
}
export declare const SettingsMenu: React.ForwardRefExoticComponent<Props & React.RefAttributes<ContextMenu>>;
export {};
