/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext } from "react";
import { LanguageContext } from "../../contexts/language";
export function useTranslator() {
  const langContext = useContext(LanguageContext);
  return langContext?.useTranslationFunction ? langContext?.useTranslationFunction() :
  //eslint-disable-next-line
  (...parameters) => "";
}
export function applyTranslation(Component) {
  //eslint-disable-next-line
  return function (props) {
    const t = useTranslator();
    const extendedProps = {
      t,
      ...props
    };
    return /*#__PURE__*/React.createElement(Component, extendedProps);
  };
}