function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * Copyright © 2024 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React from "react";
import { TabGroup } from "../tabs/tabGroup/tabGroup";
import { generateHashForValues } from "../../../utils/hash";
export class Group {
  constructor(_name, _logo, _collapsible, _contentWrappers) {
    this._name = _name;
    this._logo = _logo;
    this._collapsible = _collapsible;
    this._contentWrappers = _contentWrappers;
    _defineProperty(this, "_insideGroup", false);
    // Generate unique key based on the keys of the views.
    _defineProperty(this, "getKey", () => {
      return generateHashForValues(this._contentWrappers.map(view => view.getKey()));
    });
    _defineProperty(this, "getRoutes", () => {
      const routes = [];
      this._contentWrappers.forEach(view => {
        view.getRoutes().forEach(route => {
          routes.push(route);
        });
      });
      return routes;
    });
    // If this wrapper is located at the top of a group hierarchie (meaning without a parent group)
    // the options will be injected directly by the navbar component. Because of this frameworkInjectedOptions
    // can be of type InjectedOptionsByNavbarToWrapper.
    _defineProperty(this, "getNavbarComponent", frameworkInjectedOptions => {
      const injectedProperties = {
        navbarCollapsed: frameworkInjectedOptions.navbarCollapsed,
        insideGroup: this.getInsideGroup(),
        // As the options origin can be the navbar component itself it has to be checked whether this
        // wrapper is located inside a group.
        groupActive: this.getInsideGroup() ?
        // @ts-ignore If insideGroup is true groupActive will be contained.
        frameworkInjectedOptions.groupActive : false
      };
      return /*#__PURE__*/React.createElement(TabGroup, {
        navbarCollapsed: frameworkInjectedOptions.navbarCollapsed,
        key: this.getKey(),
        name: this._name,
        logo: this._logo ? this._logo : undefined,
        collapsible: this._collapsible,
        frameworkInjectedOptions: injectedProperties,
        wrappers: this._contentWrappers
      });
    });
    _contentWrappers.forEach(contentWrapper => {
      contentWrapper.setInsideGroup(true);
    });
  }
  get name() {
    return this._name;
  }
  getInsideGroup() {
    return this._insideGroup;
  }
  setInsideGroup(insideGroup) {
    this._insideGroup = insideGroup;
  }
}